<?php

namespace Simpler\Http\Schemas;

final class OrderSchema {
	public static $schema
		= [
			'$schema'              => 'http://json-schema.org/draft-04/schema#',
			'title'                => 'order',
			'type'                 => 'object',
			'additionalProperties' => false,
			'properties'           => [
				'user'  => [
					'description'          => 'User entry',
					'type'                 => 'object',
					'required'             => true,
					'additionalProperties' => false,
					'properties'           => [
						'email'      => [
							'type'     => 'string',
							'required' => true
						],
						'first_name' => [
							'type'     => 'string',
							'required' => true,
						],
						'last_name'  => [
							'type'     => 'string',
							'required' => true
						],
					]
				],
				'order' => [
					'type'                 => 'object',
					'required'             => false,
					'additionalProperties' => false,
					'properties'           => [
						'simpler_cart_id'    => [
							'type'     => 'string',
							'required' => true
						],
						'currency'           => [
							'type'     => 'string',
							'required' => true
						],
						'cart'               => [
							'type'     => 'array',
							'minItems' => 1,
							'items'    => [
								'type'                 => 'object',
								'required'             => true,
								'additionalProperties' => false,
								'properties'           => [
									'product_id' => [
										'type'     => 'string',
										'required' => true
									],
									'quantity'   => [
										'type'     => 'number',
										'required' => true,
										'min'      => 1
									]
								]
							]
						],
						'shipping_method_id' => [
							'type'     => 'string',
							'required' => true
						],
						'shipto'             => [
							'type'                 => 'object',
							'required'             => true,
							'additionalProperties' => false,
							'properties'           => [
								'recipient' => [
									'type'     => 'string',
									'required' => true
								],
								'phone'     => [
									'type'     => 'string',
									'required' => true
								],
								'address'   => [
									'type'     => 'string',
									'required' => true
								],
								'city'      => [
									'type'     => 'string',
									'required' => true
								],
								'postcode'  => [
									'type'     => 'string',
									'required' => true
								],
								'state'     => [
									'type' => 'string',
								],
								'country'   => [
									'type'     => 'string',
									'required' => true
								],
								'notes'     => [
									'type'     => 'string',
									'required' => true
								]
							]
						]
					]
				]
			]
		];
}
