<?php

add_action('admin_init', 'simplerwc_init_plugin');

function simplerwc_init_plugin()
{
	add_settings_section(
		'simpler_credentials',
		'Credentials',
		'simplerwc_credentials_config',
		'simpler_management'
	);

	add_settings_field(
		'simpler_api_key',
		'Simpler API Key',
		'simplerwc_echo_simpler_api_key_input',
		'simpler_management',
		'simpler_credentials'
	);

	register_setting('simpler_management', 'simpler_api_key', [
		'type' => 'string'
	]);

	add_settings_field(
		'simpler_api_secret',
		'Simpler API Secret',
		'simplerwc_echo_simpler_api_secret_input',
		'simpler_management',
		'simpler_credentials'
	);

	register_setting('simpler_management', 'simpler_api_secret', [
		'type' => 'string'
	]);

	add_settings_section(
		'simpler_custom_styles',
		'Simpler Button Custom Styling (Advanced)',
		'simplerwc_custom_styles',
		'simpler_management'
	);

	add_settings_field(
		'simpler_product_button_custom_style',
		'Product Page',
		'simplerwc_echo_simpler_product_button_custom_style',
		'simpler_management',
		'simpler_custom_styles'
	);

	register_setting('simpler_management', 'simpler_product_button_custom_style', [
		'type' => 'string',
	]);

	add_settings_field(
		'simpler_mini_cart_button_custom_style',
		'Mini Cart',
		'simplerwc_echo_simpler_mini_cart_button_custom_style',
		'simpler_management',
		'simpler_custom_styles'
	);

	register_setting('simpler_management', 'simpler_mini_cart_button_custom_style', [
		'type' => 'string',
	]);

	add_settings_field(
		'simpler_cart_page_button_custom_style',
		'Cart Page',
		'simplerwc_echo_simpler_cart_page_button_custom_style',
		'simpler_management',
		'simpler_custom_styles'
	);

	register_setting('simpler_management', 'simpler_cart_page_button_custom_style', [
		'type' => 'string',
	]);

	add_settings_field(
		'simpler_checkout_page_button_custom_style',
		'Checkout Page',
		'simplerwc_echo_simpler_checkout_page_button_custom_style',
		'simpler_management',
		'simpler_custom_styles'
	);

	register_setting('simpler_management', 'simpler_checkout_page_button_custom_style', [
		'type' => 'string',
	]);

	add_settings_section(
		'simpler_debugging',
		'Advanced Settings',
		'simplerwc_debug_config',
		'simpler_management'
	);

	add_settings_field(
		'simpler_checkout_test_mode',
		'Test Mode?',
		'simplerwc_echo_simpler_checkout_test_mode',
		'simpler_management',
		'simpler_debugging'
	);

	register_setting('simpler_management', 'simpler_checkout_test_mode', [
		'type' => 'number',
		'default' => 1
	]);

	// hidden, only accessible through {DOMAIN}/wp-admin/options.php
	add_option('simpler_checkout_root_fqdn', SIMPLERWC_DEFAULT_ROOT_FQDN);
}

function simplerwc_credentials_config()
{
}

function simplerwc_custom_styles()
{
	echo '<hr class="divider" />';
}

function simplerwc_debug_config()
{
	echo '<hr class="divider" />';
}

function simplerwc_echo_simpler_api_key_input()
{
	echo '<input name="simpler_api_key" id="simpler_api_key" type="text" style="min-width: 35%;" value="' . esc_html(get_option('simpler_api_key')) . '" />';
}

function simplerwc_echo_simpler_api_secret_input()
{
	echo '<input name="simpler_api_secret" id="simpler_api_key" type="text" style="min-width: 35%;" value="' . esc_html(get_option('simpler_api_secret')) . '" />';
}

function simplerwc_echo_simpler_product_button_custom_style()
{
	echo '<textarea name="simpler_product_button_custom_style" id="simpler_product_button_custom_style" cols=28 rows=10>' . esc_textarea(get_option('simpler_product_button_custom_style')) . '</textarea>';
}

function simplerwc_echo_simpler_mini_cart_button_custom_style()
{
	echo '<textarea name="simpler_mini_cart_button_custom_style" id="simpler_mini_cart_button_custom_style" cols=28 rows=10>' . esc_textarea(get_option('simpler_mini_cart_button_custom_style')) . '</textarea>';
}

function simplerwc_echo_simpler_cart_page_button_custom_style()
{
	echo '<textarea name="simpler_cart_page_button_custom_style" id="simpler_cart_page_button_custom_style" cols=28 rows=10>' . esc_textarea(get_option('simpler_cart_page_button_custom_style')) . '</textarea>';
}

function simplerwc_echo_simpler_checkout_page_button_custom_style()
{
	echo '<textarea name="simpler_checkout_page_button_custom_style" id="simpler_checkout_page_button_custom_style" cols=28 rows=10>' . esc_textarea(get_option('simpler_checkout_page_button_custom_style')) . '</textarea>';
}

function simplerwc_echo_simpler_checkout_test_mode()
{
	$html = '<div>';
	$html .= '<input type="checkbox" id="simpler_checkout_test_mode" name="simpler_checkout_test_mode" value="1" ' . checked(1, get_option('simpler_checkout_test_mode'), false) . ' />';
	$html .= '<label for="simpler_checkout_test_mode">Test Mode?</label>';
	$html .= '</div><div>';
	$html .= '<small>When Test Mode is enabled only logged in administrators will be able to see the Simpler Checkout buttons.</small>';
	$html .= '</div>';
	echo $html;
}

add_action('admin_menu', 'simplerwc_init_simpler_admin_dashboard');

function simplerwc_init_simpler_admin_dashboard()
{
	add_submenu_page(
		'options-general.php',
		'SimplerCheckout',
		'Simpler Checkout',
		'manage_options',
		'simpler_management',
		'simplerwc_render_homepage',
		100,
		100
	);
}

function simplerwc_render_homepage()
{
?>
	<div class="wrap">
		<h1 style="font-weight: 600; margin: 2rem 0;">Simpler. 1-Click Checkout</h1>
		<p>
			The Simpler 1-Click Checkout button lets your customers complete their purchases in seconds.
			Customers using Simpler for the first time will fill in a simple form once.
			For all their next purchases, they can complete their orders with 1 click, regardless of device or browser, and without a password.
		</p>
		<p>
			You can configure your Simpler integration here.
			<span style="font-size:.8rem;">Questions? Contact us at <a href="mailto:support@simpler.so">support@simpler.so</a></span>
		</p>
		<form action="<?php echo esc_url(admin_url('options.php')); ?>" method="POST" style="padding-top:20px;">
			<?php settings_fields('simpler_management');
			do_settings_sections('simpler_management');
			submit_button();
			?>
		</form>
	</div>
<?php
}

add_filter('plugin_action_links_' . SIMPLERWC_PLUGIN_BASENAME, 'simplerwc_add_plugin_page_settings_link');

function simplerwc_add_plugin_page_settings_link($links)
{
	return array_merge([
		'<a href="' . admin_url('options-general.php?page=simpler_management') . '">' . __('Settings') . '</a>'
	], $links);
}
