<?php

if (!(get_option('simpler_api_key') && get_option('simpler_api_secret'))) {
	error_log('MISSING SIMPLER API KEY & SECRET');
	return;
}

add_filter(
	'woocommerce_after_add_to_cart_quantity',
	'simplerwc_add_checkout_after_main_content',
	10
);

add_filter(
	'woocommerce_widget_shopping_cart_before_buttons',
	'simplerwc_render_mini_cart',
	10
);

add_filter(
	'woocommerce_proceed_to_checkout',
	'simplerwc_render_proceed_to_checkout',
	10
);

add_filter(
	'woocommerce_checkout_before_customer_details',
	'simplerwc_render_before_checkout_form',
	10
);

function simplerwc_add_checkout_after_main_content()
{
	if (!simplerwc_should_render_button()) {
		return;
	}
	global $product;
	simplerwc_simple_button("Quick Buy", "simpler-product-page");
	simplerwc_cart_contents_tag("simpler-product-payload", simplerwc_prepare_product($product));
}

function simplerwc_render_mini_cart()
{
	if (!simplerwc_should_render_button()) {
		return;
	}
	$cart          = WC()->cart;
	simplerwc_simple_button("Quick Checkout", "simpler-mini-cart");
	simplerwc_cart_contents_tag('simpler-cart-payload', simplerwc_prepare_cart($cart));
	simplerwc_mini_cart_event(); //minicarts are not woocommerce built-ins and as such have no specific jquery event to rely on
}

function simplerwc_render_proceed_to_checkout()
{
	if (!simplerwc_should_render_button()) {
		return;
	}
	$cart          = WC()->cart;
	simplerwc_simple_button("Quick Checkout", "simpler-proceed-to-checkout");
	simplerwc_cart_contents_tag('simpler-cart-payload', simplerwc_prepare_cart($cart));
}

function simplerwc_render_before_checkout_form()
{
	if (!simplerwc_should_render_button()) {
		return;
	}
	$cart          = WC()->cart;
	simplerwc_marquee_button('Quick Checkout', "simpler-before-checkout-form");
	simplerwc_cart_contents_tag('simpler-cart-payload', simplerwc_prepare_cart($cart));
}

function simplerwc_simple_button($text, $positionId)
{
	echo simplerwc_button_style($positionId);
?>
	<div class="simpler-container <?php echo $positionId; ?>">
		<div class="simpler-wrap">
			<?php
			echo simplerwc_button_template($text, $positionId === "simpler-product-page");
			echo simplerwc_button_separator_template();
			?>
		</div>
	</div>
<?php
}

function simplerwc_marquee_button($text, $positionId)
{
	echo simplerwc_button_style($positionId);
?>
	<div class="simpler-container <?php echo $positionId; ?>">
		<div class="simpler-wrap simpler-marquee-wrap">
			<div class="simpler-marquee-top">Safer, Faster, Simpler</div>
			<?php echo simplerwc_button_template($text, $positionId === "simpler-product-single"); ?>
			<div class="simpler-marquee-bottom">OR</div>
		</div>
	</div>
<?php
}

function simplerwc_button_style($positionId)
{
	switch ($positionId) {
		case "simpler-product-page":
			$style = get_option("simpler_product_button_custom_style");
			break;
		case "simpler-mini-cart":
			$style = get_option("simpler_mini_cart_button_custom_style");
			break;
		case "simpler-proceed-to-checkout":
			$style = get_option("simpler_cart_page_button_custom_style");
			break;
		case "simpler-before-checkout-form":
			$style = get_option("simpler_checkout_page_button_custom_style");
			break;
		default:
			return false;
	}
	return '<style type="text/css">' . esc_html($style) . '</style>';
}

function simplerwc_cart_contents_tag($id, $cart)
{
	$cartPayload = base64_encode(json_encode([
		'cart' => $cart,
		'currency' => get_woocommerce_currency(),
	]));
?>
	<input id="<?php echo $id ?>" type="hidden" value="<?php echo $cartPayload ?>" />
<?php
}

function simplerwc_mini_cart_event()
{ ?>
	<script type="text/javascript">
		window.dispatchEvent(new CustomEvent('mini_cart_loaded'));
	</script>
<?php }

function simplerwc_prepare_product($product)
{
	return [
		simplerwc_get_product_attributes($product)
	];
}

function simplerwc_prepare_cart($cart)
{
	return array_reduce($cart->get_cart_contents(), function ($acc, $el) use ($cart) {
		$product = $cart->get_cart_item($el['key']);
		array_push($acc, simplerwc_get_product_attributes($product['data'], $product['quantity']));
		return $acc;
	}, []);
}

function simplerwc_get_product_attributes($product, $qty = null)
{
	$attrs = [
		'product_id'         => strval($product->get_id()),
		'in_stock'           => $product->is_in_stock(),
		'backorders_allowed' => $product->backorders_allowed(),
		'stock_quantity'     => $product->get_stock_quantity()
	];
	if (is_a($product, 'WC_Product_Simple')) {
		$attrs['product_type'] = 'simple';
	}
	if (is_a($product, 'WC_Product_Variable')) {
		$attrs['product_type'] = 'variable';
		$attrs['variations']   = array_map(function ($el) use ($qty) {
			return simplerwc_get_product_attributes(wc_get_product($el['variation_id']), $qty);
		}, $product->get_available_variations());
	}
	if (is_a($product, 'WC_Product_Variation')) {
		$attrs['product_type'] = 'variable';
		$attrs['variations']   = $product->get_variation_attributes();
	}

	if ($qty) {
		$attrs['quantity'] = $qty;
	}

	return $attrs;
}

function simplerwc_should_render_button()
{
	return !get_option('simpler_checkout_test_mode') || in_array('administrator', wp_get_current_user()->roles, true);
}
